use std::collections::HashSet;
use std::convert::TryFrom;
use std::error::Error;

use rusqlite::Row;
use serde_derive::{Deserialize, Serialize};

use crate::id::Id;
use crate::world::{Area, AreaType};

#[derive(Debug, Deserialize, Serialize)]
pub struct Zone {
	pub id: Id,
	pub parent: Id,
	pub name: String,
	pub users_visible: bool,
	pub areas: HashSet<Id>,
}

impl Area for Zone {
	fn id(&self) -> Id {
		self.id
	}

	fn parent(&self) -> Id {
		self.parent
	}

	fn name(&self) -> String {
		self.name.to_owned()
	}

	fn visible(&self) -> bool {
		self.users_visible
	}

	fn area_type(&self) -> AreaType {
		AreaType::Zone
	}
}

impl<'a> TryFrom<&Row<'a>> for Zone {
	type Error = Box<dyn Error>;

	fn try_from(row: &Row) -> Result<Self, Self::Error> {
		Ok(Self {
			id: row.get("id")?,
			parent: row.get("parent")?,
			name: row.get("name")?,
			users_visible: row.get("users_visible")?,
			areas: HashSet::new(),
		})
	}
}
